Europe class final

Represents the continent of Europe.

This class extends the Continent class and sets its name property to "Europe".

Example:

import 'package:sealed_countries/sealed_countries.dart';

void main() {
  const europe = Europe();
  assert(europe.name == 'Europe');
}
Inheritance

Constructors

Europe()
Creates a new Europe instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of the region.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({bool short = true}) String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited