GiniExtension extension

Provides extension methods for Gini class. Contains common methods for example copyWith, toMap, fromMap, etc, that are common to all package's submodels.

on

Properties

dateTime DateTime

Available on Gini, provided by the GiniExtension extension

Converts the year field of this Gini object to a DateTime object.
no setter

Methods

copyWith({int? year, double? coefficient}) Gini

Available on Gini, provided by the GiniExtension extension

Creates a copy of this object with the given fields replaced with the new values.
toMap() Map<String, num>

Available on Gini, provided by the GiniExtension extension

Converts this object object to a JSON like map.

Static Methods

fromMap(JsonMap map) Gini

Available on Gini, provided by the GiniExtension extension

Creates a new instance of this object from a JSON like map.