dateTime property

DateTime get dateTime

Converts the year field of this Gini object to a DateTime object.

Returns a DateTime object that represents the date and time corresponding to the start of the year in which this Gini object was recorded.

Example usage:

import 'package:sealed_countries/sealed_countries.dart';

void main() {
  final gini = const Gini(year: 2020, coefficient: 32.0);
  final dateTime = gini.dateTime;
  assert(dateTime.year == 2020);
}

Implementation

DateTime get dateTime => DateTime(year);