WorldCountryDateTime extension
Provides extension methods for working with time zones and DateTime objects related to a WorldCountry object.
- on
Properties
-
tzUtcDurations
→ List<
UtcDurationDifference> -
Available on WorldCountry, provided by the WorldCountryDateTime extension
Returns an unmodifiable list of UtcDurationDifference objects representing the time differences between Coordinated Universal Time (UTC) and the time zones in the timezones list of the WorldCountry object.no setter
Static Methods
-
toAdd(
String timezone) → bool? -
Available on WorldCountry, provided by the WorldCountryDateTime extension
Returns a boolean indicating whether the given timezone string indicates an offset to add to UTC. -
tzDuration(
String timezone) → Duration? -
Available on WorldCountry, provided by the WorldCountryDateTime extension
Returns a Duration object representing the offset from UTC indicated by the given timezone string.
Constants
- minus → const String
- The string for a negative UTC offset from the timezone.
- plus → const String
- The string for a positive UTC offset from the timezone.
- timezoneValueLength → const int
- The length of the string value for a timezone offset.
- utcString → const String
- The string representation of Coordinated Universal Time (UTC).